# LinkML Configuration parameters for LinkML model generation
The parameters used to create and generate a new model derived from the LinkML Model Template

## [Documentation](https://linkml.github.io/template-config-model/)
